action

Function action 

fn action(globals: &'static Globals, signal: c_int)
Our global signal handler for all signals registered by this module.

The purpose of this signal handler is to primarily:

  1. Flag that our specific signal was received (e.g. store an atomic flag)
  2. Wake up the driver by writing a byte to a pipe

Those two operations should both be async-signal safe.