fn signal_enable(signal: SignalKind, handle: &Handle) -> Result<()>Expand description
Enables this module to receive signal notifications for the signal
provided.
This will register the signal handler if it hasn’t already been registered, returning any error along the way if that fails.